@@ -1,11 +1,14 @@
+
+#use_data(trans_df,nt_coi_PHMM,aa_coi_PHMM,nt_coi_PHMM,example_nt_string,example_barcode_data, overwrite=TRUE, internal=TRUE)
+
+
 ###############################################################################
 #' Nucleotide profile hidden Markov model for coi5p.
 #'
 #' This model is stored in the coi5p package and was trained on a representative
 #' sample of the barcode of life database (http://www.boldsystems.org/index.php).
 #'
-#' @keywords internal
-"nt_PHMM"
+"nt_coi_PHMM"
 ###############################################################################
 
 ###############################################################################
@@ -14,8 +17,7 @@
 #' This model is stored in the coi5p package and was trained on a representative
 #' sample of the barcode of life database (http://www.boldsystems.org/index.php).
 #'
-#' @keywords internal
-"aa_PHMM"
+"aa_coi_PHMM"
 ###############################################################################
 
 ###############################################################################
